Bifrost: Data Fields

Bifrost

Here is a list of all documented struct and union fields with links to the struct/union documentation for each field:

### - u -

- UnitigColors() : UnitigColors
- UnitigColors_const_iterator() : UnitigColors::UnitigColors_const_iterator
- unitigIterator() : unitigIterator< Unitig_data_t, Graph_data_t, is_const >
- UnitigMap() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- UnitigMapBase() : UnitigMapBase
- update : CDBG_Build_opt
- useMercyKmers : CDBG_Build_opt